==> colord-gtk-0.1.21.tgz: include/colord-1/colord-gtk.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2010-2011 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU Lesser General Public License Version 2.1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 */

/**
 * SECTION:colord
 * @short_description: Client objects for accessing colord with GTK
 *
 * These objects allow client programs to get access to profiles.
 *
 * See also: #CdClient, #CdDevice
 */

#ifndef __COLORD_GTK_H__
#define __COLORD_GTK_H__

#define __COLORD_H_INSIDE__

#include <gtk/gtk.h>

#include <colord/cd-client.h>
#include <colord/cd-device.h>
#include <colord/cd-profile.h>
#include <colord/cd-color.h>
#include <colord-gtk/cd-sample-window.h>
#include <colord-gtk/cd-window.h>
#include <colord-gtk/cd-window-sync.h>

#undef __COLORD_H_INSIDE__

#endif /* __COLORD_GTK_H__ */

==> colord-gtk-0.1.23.tgz: include/colord-1/colord-gtk.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2010-2011 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU Lesser General Public License Version 2.1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 */

/**
 * SECTION:colord-gtk
 * @short_description: Client objects for accessing colord with GTK
 *
 * These objects allow client programs to get access to profiles.
 *
 * See also: #CdClient, #CdDevice
 */

#ifndef __COLORD_GTK_H__
#define __COLORD_GTK_H__

#define __COLORD_GTK_H_INSIDE__

#include <gtk/gtk.h>
#include <colord.h>

#include <colord-gtk/cd-sample-window.h>
#include <colord-gtk/cd-version.h>
#include <colord-gtk/cd-window.h>
#include <colord-gtk/cd-window-sync.h>

#undef __COLORD_GTK_H_INSIDE__

#endif /* __COLORD_GTK_H__ */
